@@ -53,7 +53,7 @@ class DiegoOperator(PythonOperator):
         data_format = json.dumps({
             "destinationId": self.cube_id,
             "file": file_path,
-            "pattern": ".*part.*",
+            "pattern": ".*.parquet",
             "fullLoad": self.full_load
             })
 
@@ -71,39 +71,36 @@ class DiegoOperator(PythonOperator):
 
         return response
 
-    def __upload_df_to_s3_temp(self, df: pd.DataFrame, path, pandas_kwargs=None):
+    def __upload_df_to_s3_temp(self, df: pd.DataFrame, path, part_number, pandas_kwargs=None):
         if pandas_kwargs is None:
             pandas_kwargs = dict()
-        df.to_parquet(path=path)
+        df.to_parquet(path=f"{path}/{part_number}.parquet")
 
         return True
 
 
-    def __upload_pandas_df_to_diego(self, df, pandas_kwargs=None):
+    def __upload_pandas_df_to_diego(self, df, path, part_number, pandas_kwargs=None):
         if pandas_kwargs is None:
             pandas_kwargs = dict()
         rows = df.shape[0]
-        temp_file_path = f"s3://cortex-data-lakehouse-metastore-development/temp-files-diego/{self.task_id}/{self.cube_id}/{str(hash(datetime.utcnow().isoformat()))}"
 
         if rows <= self.diego_chunksize:
-            self.__upload_df_to_s3_temp(df=df, path=temp_file_path, pandas_kwargs=pandas_kwargs)
+            self.__upload_df_to_s3_temp(df=df, path=path, pandas_kwargs=pandas_kwargs)
         else:
             list_df = [df[i:i + self.diego_chunksize] for i in range(0, df.shape[0], self.diego_chunksize)]
             for i, df_element in enumerate(list_df):
-                self.__upload_df_to_s3_temp(df=df_element, path=temp_file_path, pandas_kwargs=pandas_kwargs)
+                self.__upload_df_to_s3_temp(df=df_element, path=path, part_number=part_number, pandas_kwargs=pandas_kwargs)
                 time.sleep(self.sleep_between_chunks)
 
-        return self.send_file_path_to_diego(temp_file_path)
-
-    def upload_df_to_diego(self, df, pandas_kwargs=None):
+    def upload_df_to_diego(self, df, path, part_number, pandas_kwargs=None):
         if pandas_kwargs is None:
             pandas_kwargs = dict()
         if isinstance(df, pd.DataFrame):
-            return self.__upload_pandas_df_to_diego(df=df, pandas_kwargs=pandas_kwargs)
+            return self.__upload_pandas_df_to_diego(df=df, path=path, part_number=part_number, pandas_kwargs=pandas_kwargs)
         else:
             raise TypeError(f'df must be a pandas DataFrame object, it is type: {type(df)}')
 
-    def __execute_df(self, df):
+    def __execute_df(self, df, part_number, path):
         if not isinstance(df, pd.DataFrame):
             raise TypeError(f'The callable must return a pandas DataFrame object, it returned: {type(df)}')
 
@@ -112,16 +109,22 @@ class DiegoOperator(PythonOperator):
         elif not self.ignore_empty_dataframe and df.shape[0] == 0:
             raise ValueError(f'The dataframe passed is empty {df.shape}, please use a valid dataframe')
 
-        return self.upload_df_to_diego(df, pandas_kwargs=self.pandas_kwargs)
+        return self.upload_df_to_diego(df, path=path, part_number=part_number, pandas_kwargs=self.pandas_kwargs)
 
 
     def execute(self, context):
         df = super().execute(context)
+
+        temp_file_path = f"s3://cortex-data-lakehouse-metastore-development/temp-files-diego/{self.task_id}/{self.cube_id}/{str(hash(datetime.utcnow().isoformat()))}"
+
         if isinstance(df, collections.Iterator):
-            for df_part in df:
-                self.__execute_df(df=df_part)
+            for part_number, df_part in enumerate(df):
+                self.__execute_df(df=df_part, part_number=part_number, path=temp_file_path)
         else:
-            self.__execute_df(df=df)
+            self.__execute_df(df=df, part_number=1, path=temp_file_path)
+
+        self.send_file_path_to_diego(temp_file_path)
+
         if not self.ignore_empty_dataframe:
             raise ValueError('There were no dataframes written to Diego. Please check if your dataframes are empty')
 
