@@ -752,7 +752,7 @@ def bronze_to_silver(
                 output_db_table : {output_db_table},
                 description : {tbl_properties.get('cortex.description')},
                 """)
-                set_comment_table(catalog_name, output_db_table, tbl_properties.get('cortex.description'))
+                set_comment_table(catalog_name, f"silver.{tbl_properties.get('cortex.tableName')}", tbl_properties.get('cortex.description'))
 
             except Exception as e:
                 print(e)
@@ -904,7 +904,7 @@ def silver_to_gold(
                     .format('delta')\
                     .mode('append')\
                     .saveAsTable("cortex.data_governance_quality.tables")
-                set_comment_table(catalog_name, output_db_table, tbl_properties.get('cortex.description'))
+                set_comment_table(catalog_name, f"gold.{tbl_properties.get('cortex.tableName')}", tbl_properties.get('cortex.description'))
 
             except Exception as e:
                 print(e)
